==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/vi/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Trạng thái <strong>CronJob</strong>',
    '<strong>Queue</strong> Status' => 'Trạng thái <strong>Queue</strong>',
    'About HumHub' => 'Về HumHub',
    'Background Jobs' => 'Background Jobs',
    'Base URL' => 'Base URL',
    'Checking HumHub software prerequisites.' => 'Kiểm tra các yêu cầu tiên quyết cần có để cài đặt HumHub.',
    'Database' => 'Cơ sở dữ liệu',
    'Database migration results:' => 'Kết quả di chuyển CSDL',
    'Delayed' => 'Hoãn',
    'Displaying {count} entries per page.' => 'Hiển thị {count} mục trên một trang',
    'Done' => 'Hoàn tất',
    'Driver' => 'Driver',
    'Error' => 'Lỗi',
    'Flush entries' => 'Flush entries',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub is currently in debug mode. Disable it when running on production!',
    'Last run (daily):' => 'Last run (daily):',
    'Last run (hourly):' => 'Last run (hourly):',
    'Licences' => 'Licences',
    'Logging' => 'Đăng nhập',
    'Never' => 'Không bao giờ',
    'Other' => 'Khác',
    'Permissions' => 'Quyền truy cập',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Vui lòng tham khảo tài liệu để setup Cronjobs và Queue.',
    'Prerequisites' => 'Điều kiện tiên quyết',
    'Queue successfully cleared.' => 'Queue successfully cleared.',
    'Re-Run tests' => 'Re-Run tests',
    'Reserved' => 'Reserved',
    'Search index rebuild in progress.' => 'Đang xây dựng lại chỉ mục tìm kiếm.',
    'See installation manual for more details.' => 'Xem tài liệu hưỡng dẫn cài đặt để biết chi tiết.',
    'Settings' => 'Cấu hình',
    'The current main HumHub database name is ' => 'CSDL HumHub chính hiện tại là',
    'There is a new update available! (Latest version: %version%)' => 'Đã có bản cập nhật mới! (Latest version: %version%)',
    'This HumHub installation is up to date!' => 'Bản cài đặt HumHub này đã được cập nhật mới nhất!',
    'Total {count} entries found.' => 'Tổng {count} mục được tìm thấy.',
    'Waiting' => 'Đợi',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Search term...' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Warning' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/vi/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Trạng thái <strong>CronJob</strong>',
    '<strong>Queue</strong> Status' => 'Trạng thái <strong>Queue</strong>',
    'About HumHub' => 'Về HumHub',
    'Background Jobs' => 'Background Jobs',
    'Base URL' => 'Base URL',
    'Checking HumHub software prerequisites.' => 'Kiểm tra các yêu cầu tiên quyết cần có để cài đặt HumHub.',
    'Database' => 'Cơ sở dữ liệu',
    'Database migration results:' => 'Kết quả di chuyển CSDL',
    'Delayed' => 'Hoãn',
    'Displaying {count} entries per page.' => 'Hiển thị {count} mục trên một trang',
    'Done' => 'Hoàn tất',
    'Driver' => 'Driver',
    'Error' => 'Lỗi',
    'Flush entries' => 'Flush entries',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub is currently in debug mode. Disable it when running on production!',
    'Last run (daily):' => 'Last run (daily):',
    'Last run (hourly):' => 'Last run (hourly):',
    'Licences' => 'Licences',
    'Logging' => 'Đăng nhập',
    'Never' => 'Không bao giờ',
    'Other' => 'Khác',
    'Permissions' => 'Quyền truy cập',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Vui lòng tham khảo tài liệu để setup Cronjobs và Queue.',
    'Prerequisites' => 'Điều kiện tiên quyết',
    'Queue successfully cleared.' => 'Queue successfully cleared.',
    'Re-Run tests' => 'Re-Run tests',
    'Reserved' => 'Reserved',
    'Search index rebuild in progress.' => 'Đang xây dựng lại chỉ mục tìm kiếm.',
    'See installation manual for more details.' => 'Xem tài liệu hưỡng dẫn cài đặt để biết chi tiết.',
    'Settings' => 'Cấu hình',
    'The current main HumHub database name is ' => 'CSDL HumHub chính hiện tại là',
    'There is a new update available! (Latest version: %version%)' => 'Đã có bản cập nhật mới! (Latest version: %version%)',
    'This HumHub installation is up to date!' => 'Bản cài đặt HumHub này đã được cập nhật mới nhất!',
    'Total {count} entries found.' => 'Tổng {count} mục được tìm thấy.',
    'Waiting' => 'Đợi',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    'Assets' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Outstanding database migrations:' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Runtime' => '',
    'Search term...' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Warning' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
